library(vegan)

# Use epsilon for correction
EPS <- sqrt(.Machine$double.eps)

#Read otu table and metadata
otu_table = read.delim('otu_table.txt', row.names = 1)
env_table = read.delim('env_table.txt', row.names = 1)

# Run 999 iterations
n_perm = 999

f_perms = NULL
F_Model = NULL
R_perms = NULL
for(i in 1:n_perm)
{
  print(i) # print curent iteration
  otu_table_rrf = rrarefy(x = t(otu_table), sample = min(colSums(otu_table))) # permute otu table
  dist = vegdist(x = otu_table_rrf) # calculate distance
  res = adonis(dist ~ env_table$Chlorophyll, permutations = 1) # run permanova with 1 permutation
  f_perms = c(f_perms, res$f.perms)
  F_Model = c(F_Model, res$aov.tab$F.Model[1]) # get f statistics
  R_perms = c(R_perms, res$aov.tab$R2[1]) # get R value
}
Pval = (sum(f_perms >= F_Model - EPS) + 1) / (n_perm + 1) # calculate P value from 1000
Rval = sum(R_perms) / n_perm # Average R value
cat("P =", Pval, "; R2 =", Rval)
